@@ -31,7 +31,6 @@
 #include <KMessageBox>
 #include <KRecentFilesAction>
 #include <KSharedConfig>
-#include <KToolBarPopupAction>
 #include <KNSWidgets/Action>
 #include "interpreter/errormsg.h"
 #include "interpreter/translator.h"
@@ -415,9 +414,10 @@ void MainWindow::setupActions()
 	QActionGroup* runSpeedGroup = new QActionGroup(this);
 
 	// The run action collection, this is used in the toolbar to create a dropdown menu on the run button
-	KToolBarPopupAction* runSpeedAction = new KToolBarPopupAction(QIcon::fromTheme(QStringLiteral("media-playback-start")), i18n("&Run"), this);
-	connect(runSpeedAction, &KToolBarPopupAction::triggered, this, &MainWindow::run);
-	QMenu* runSpeedActionMenu = runSpeedAction->menu();
+	QAction* runSpeedAction = new QAction(QIcon::fromTheme(QStringLiteral("media-playback-start")), i18n("&Run"), this);
+	connect(runSpeedAction, &QAction::triggered, this, &MainWindow::run);
+	QMenu* runSpeedActionMenu = new QMenu(this);
+	runSpeedAction->setMenu(runSpeedActionMenu);
 	actionCollection()->addAction(QStringLiteral("run_speed"), runSpeedAction);
 	runSpeedActionMenu->setStatusTip(i18n("Execute the program, or use the drop down menu to select the run speed"));
 	runSpeedActionMenu->setWhatsThis(i18n("Run: Execute the program, or use the drop down menu to select the run speed"));
@@ -982,10 +982,10 @@ void MainWindow::addToRecentFiles(const QUrl &url)
 
 void MainWindow::readConfig()
 {
-	KConfigGroup config(KSharedConfig::openConfig(), "General Options");
+	KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General Options"));
 // 	m_paShowStatusBar->setChecked(config->readEntry("ShowStatusBar", QVariant(false)).toBool());
 // 	m_paShowPath->setChecked(config->readEntry("ShowPath", QVariant(false)).toBool());
-	recentFilesAction->loadEntries(KSharedConfig::openConfig()->group("Recent Files"));
+	recentFilesAction->loadEntries(KSharedConfig::openConfig()->group(QStringLiteral("Recent Files")));
 	QString lang_code(config.readEntry("currentLanguageCode", QVariant(QString())).toString());
 	if (lang_code.isEmpty()) lang_code = QStringLiteral("en_US");  // null-string are saved as empty-strings
 	setCurrentLanguage(lang_code);
@@ -997,10 +997,10 @@ void MainWindow::readConfig()
 
 void MainWindow::writeConfig()
 {
-	KConfigGroup config(KSharedConfig::openConfig(), "General Options");
+	KConfigGroup config(KSharedConfig::openConfig(), QStringLiteral("General Options"));
 // 	config.writeEntry("ShowStatusBar",m_paShowStatusBar->isChecked());
 // 	config.writeEntry("ShowPath",m_paShowPath->isChecked());
-	recentFilesAction->saveEntries(KSharedConfig::openConfig()->group( "Recent Files"));
+	recentFilesAction->saveEntries(KSharedConfig::openConfig()->group(QStringLiteral("Recent Files")));
 	config.writeEntry("currentLanguageCode", currentLanguageCode);
 	config.sync();
 }
